﻿#region License
// Copyright 2010 Buu Nguyen (http://www.buunguyen.net/blog)
// 
// Licensed under the Apache License, Version 2.0 (the "License"); 
// you may not use this file except in compliance with the License. 
// You may obtain a copy of the License at 
// 
// http://www.apache.org/licenses/LICENSE-2.0 
// 
// Unless required by applicable law or agreed to in writing, software 
// distributed under the License is distributed on an "AS IS" BASIS, 
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
// See the License for the specific language governing permissions and 
// limitations under the License.
// 
// The latest version of this file can be found at http://combres.codeplex.com
#endregion

using System.Collections.Generic;
using System.Xml.Linq;

namespace Combres
{
    /// <summary>
    /// Represents a binder which can bind values specified in a list of <code>XElement</code> to an object.
    /// </summary>
    public interface IObjectBinder
    {
        /// <summary>
        /// Constructs an object of type <typeparamref name="T"/> and bind the values in <paramref name="parameters"/> into that object.
        /// </summary>
        /// <typeparam name="T">The target object type to construct and bind values.</typeparam>
        /// <param name="parameters">The parameter list.</param>
        /// <returns>A newly constructed object of type <typeparamref name="T"/> with properties specified from <paramref name="parameters"/>.</returns>
        T Bind<T>(IEnumerable<XElement> parameters);

        /// <summary>
        /// Bind the values in <paramref name="parameters"/> into an existing object.
        /// </summary>
        /// <param name="instance">The object whose properties are to be set.</param>
        /// <param name="parameters">The parameter list.</param>
        void Bind(IEnumerable<XElement> parameters, object instance);
    }
}
