﻿#region License
// Copyright 2010 Buu Nguyen (http://www.buunguyen.net/blog)
// 
// Licensed under the Apache License, Version 2.0 (the "License"); 
// you may not use this file except in compliance with the License. 
// You may obtain a copy of the License at 
// 
// http://www.apache.org/licenses/LICENSE-2.0 
// 
// Unless required by applicable law or agreed to in writing, software 
// distributed under the License is distributed on an "AS IS" BASIS, 
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
// See the License for the specific language governing permissions and 
// limitations under the License.
// 
// The latest version of this file can be found at http://combres.codeplex.com
#endregion

using System.Collections.Generic;
using System.Xml.Linq;

namespace Combres.Minifiers
{
    /// <summary>
    /// JavaScript minifier which delegates the minification process to the Google Closure Compiler (http://closure-compiler.appspot.com/).
    /// </summary>
    public sealed class ClosureJSMinifier : IResourceMinifier, IParametersReceiver
    {
        /// <inheritdoc cref="IParametersReceiver.Binder" />
        public IObjectBinder Binder { get; set; }

        /// <inheritdoc cref="IParametersReceiver.Parameters" />
        public IList<XElement> Parameters { get; set; }

        /// <summary>
        /// The URL of the Closure REST API.
        /// </summary>
        public string ApiUrl { get; set; }

        /// <summary>
        /// Compilation level, either ADVANCED_OPTIMIZATIONS or SIMPLE_OPTIMIZATIONS.
        /// Check out this webpage for more information: http://code.google.com/closure/compiler/docs/api-tutorial3.html.
        /// Default is SIMPLE_OPTIMIZATIONS
        /// </summary>
        public string CompilationLevel { get; set; }

        /// <inheritdoc cref="IResourceMinifier.Minify" />
        public string Minify(Settings settings, ResourceSet resourceSet, string combinedContent)
        {
            Binder.Bind(Parameters, this);
            var level = (ClosureCodeRequest.CompilationLevel)CompilationLevel.ConvertToType(
                typeof(ClosureCodeRequest.CompilationLevel), 
                ClosureCodeRequest.CompilationLevel.Simple);
            var request = new ClosureCodeRequest(ApiUrl, level, combinedContent);
            return request.GetCode();
        }
    }
}
